parse_header_chunk

Function parse_header_chunk 

pub fn parse_header_chunk(chunk: &[u8]) -> Result<JsValue, JsValue>
Parse header metadata + index from a chunk that starts at message offset 0 (the preamble). Stops at the first data-object or preceder frame. Returns nulls for frames that fall outside the supplied chunk so TS can decide to widen its Range fetch.